.. _server_module:

:mod:`socketio.server`
======================

This is the component used to hook Gevent and its WSGI server to
the WSGI app to be served, while dispatching any Socket.IO related
activities to the `handler` and the `transports`.

.. automodule:: socketio.server
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__
